@@ -2,7 +2,7 @@ from django.utils.translation import gettext_lazy as _
 from rest_framework_simplejwt.authentication import JWTAuthentication
 from rest_framework_simplejwt.exceptions import InvalidToken
 
-from utils import get_protect_key
+from auth_protection.utils import get_protect_key
 
 
 class JWTAuthProtection(JWTAuthentication):
